Struct amazon_sp_merchant_fulfillment::models::get_eligible_shipment_services_result::GetEligibleShipmentServicesResult
source · [−]pub struct GetEligibleShipmentServicesResult {
pub shipping_service_list: Vec<ShippingService>,
pub rejected_shipping_service_list: Option<Vec<RejectedShippingService>>,
pub temporarily_unavailable_carrier_list: Option<Vec<TemporarilyUnavailableCarrier>>,
pub terms_and_conditions_not_accepted_carrier_list: Option<Vec<TermsAndConditionsNotAcceptedCarrier>>,
}Expand description
GetEligibleShipmentServicesResult : The payload for the getEligibleShipmentServices operation.
Fields
shipping_service_list: Vec<ShippingService>A list of shipping services offers.
rejected_shipping_service_list: Option<Vec<RejectedShippingService>>List of services that were for some reason unavailable for this request
A list of temporarily unavailable carriers.
terms_and_conditions_not_accepted_carrier_list: Option<Vec<TermsAndConditionsNotAcceptedCarrier>>List of carriers whose terms and conditions were not accepted by the seller.
Implementations
sourceimpl GetEligibleShipmentServicesResult
impl GetEligibleShipmentServicesResult
sourcepub fn new(
shipping_service_list: Vec<ShippingService>
) -> GetEligibleShipmentServicesResult
pub fn new(
shipping_service_list: Vec<ShippingService>
) -> GetEligibleShipmentServicesResult
The payload for the getEligibleShipmentServices operation.